@@ -62,7 +62,7 @@ class DirectSearchAlgorithm(OptimizationAlgorithm):
         # Optimal algorithm variables ###########################################################
         ###########################################################################################
         # Starting FoM
-        self.best_FoM = 1e10
+        # self.best_FoM = 1e10  # defined in parent class
         ###########################################################################################
         # Pulses, Parameters object ###########################################################
         ###########################################################################################
